<?php
namespace Controller;

use Zeedhi\DevOps\Util\Utilities;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\DevOps\Util\Environment;
use Util\InstanceProvider;

class ProductServer extends \Generated\Controller\ProductServer {

    private $environment;

    public function __construct(Manager $dataSourceManager, Environment $environment) {
        parent::__construct($dataSourceManager);
        $this->environment = $environment;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response){
        $request->getFilterCriteria()->addCondition("ORGANIZATION_ID", "=", $this->environment->getCurrentOrganizationId());
        parent::find($request, $response);
    }

	public function save(DTO\Request $request, DTO\Response $response, $showMessage = true) {
        $dataSet     = $request->getDataSet();
        $showMessage = Utilities::verifyShowMessage($dataSet);
        parent::save($request, $response, $showMessage);
    }
    
    public function findProductWithServerBasePath(Request\Filter $request, Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $productServer = InstanceProvider::getService()->getProductServer()->findProductWithServerBasePath($conditions);
            $response->addDataSet(new DataSet('productWithServerBasePath', $productServer));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }
}