<?php
/**
 * Created by PhpStorm.
 * User: phillipesilva
 * Date: 24/02/2016
 * Time: 12:32
 */

namespace Service;

use Doctrine\ORM\EntityManager;
use Zeedhi\DevOps\Util\Utilities;
use Zeedhi\DevOps\Util\Environment;

class Branch {
    /** @var EntityManager $entityManager */
    protected $entityManager;
    /** @var Environment $environment */
    protected $environment;
    /** @var \Zeedhi\DevOps\Model\Configurationmanager\Repositories\Branch $branchRepository */
    protected $branchRepository;
    /** @var \Zeedhi\DevOps\Model\Configurationmanager\Repositories\Subrelease $subreleaseRepository */
    protected $subreleaseRepository;
    /** @var \Zeedhi\DevOps\Model\Projectmanagement\Repositories\Project $projectRepository */
    protected $projectRepository;
    /** @var \Zeedhi\DevOps\Model\Projectmanagement\Repositories\TaskBranches $taskBranchesRepository */
    protected $taskBranchesRepository;

    /**
     * @param EntityManager $entityManager
     * @param Environment $environment
     */
    public function __construct(EntityManager $entityManager, Environment $environment) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->branchRepository = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Branch');
        $this->subreleaseRepository = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Subrelease');
        $this->projectRepository = $this->entityManager->getRepository(Utilities::PROJECT_MANAGEMENT_ENTITY_DIR . 'Project');
        $this->taskBranchesRepository = $this->entityManager->getRepository(Utilities::PROJECT_MANAGEMENT_ENTITY_DIR . 'TaskBranches');
    }

    /**
     * @param $subReleaseId
     * @return array
     */
    public function findBranchesBySubRelease($subReleaseId, $filter = null) {
        /** @var \Zeedhi\DevOps\Model\Configurationmanager\Repositories\Branch $branchRepository */
        $branchRepository = $this->entityManager->getRepository(Utilities::CONFIGURATION_MANAGER_ENTITY_DIR . 'Branch');
        $organizationId = $this->environment->getOrganizationId();
        return $branchRepository->findBranchesWithTaskInfoBySubRelease($subReleaseId,$organizationId, $filter);
    }

    /**
     * @param $branchNames
     * @param $productId
     * @param $subreleaseId
     * @return array
     */
    public function findBranchByNameAndProduct($branchNames, $productId, $subreleaseId) {
        $organizationId = $this->environment->getOrganizationId();
        $firstProject = $this->projectRepository->findFirstProjectByOrganization($organizationId);
        $subrelease = $this->subreleaseRepository->find($subreleaseId);
        $isPmUtilization = count($firstProject) > 0 && $subrelease->getProject();
        $branchNamesFilter = "AND ". Utilities::fixBugWhereINQuery($branchNames, "BR.NAME", false, true);
        $branches = $this->branchRepository->findBranchByNameAndProduct($branchNamesFilter, $productId, $isPmUtilization, $organizationId, $subreleaseId);
        $branchNamesResults = [];
        foreach($branches as $branch){
            array_push($branchNamesResults, $branch["NAME"]);
        }
        foreach($branchNames as $branchName){
            /** @var \Zeedhi\DevOps\Model\Projectmanagement\Repositories\TaskBranches $taskBranches */
            $taskBranches = $this->taskBranchesRepository->findOneBy(array('name' => $branchName));
            if(!in_array($branchName, $branchNamesResults)) {
                array_push($branches, array(
                    'ID' => '',
                    'NAME' => $branchName,
                    'SUBRELEASE_ID' => 1,
                    'VALIDATE_BRANCH' =>  $isPmUtilization && empty($taskBranches) ? 'INVISIBLE_BRANCH' : 'VISIBLE_BRANCH'
                ) );
            }

        }
        return $branches;
    }
} 